Ansys ModelCenter Workflow
==========================
|pyansys| |python| |pypi| |codecov| |GH-CI| |MIT| |black| |pre-commit|

.. |pyansys| image:: https://img.shields.io/badge/Py-Ansys-ffc107.svg?logo=data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAIAAACQkWg2AAABDklEQVQ4jWNgoDfg5mD8vE7q/3bpVyskbW0sMRUwofHD7Dh5OBkZGBgW7/3W2tZpa2tLQEOyOzeEsfumlK2tbVpaGj4N6jIs1lpsDAwMJ278sveMY2BgCA0NFRISwqkhyQ1q/Nyd3zg4OBgYGNjZ2ePi4rB5loGBhZnhxTLJ/9ulv26Q4uVk1NXV/f///////69du4Zdg78lx//t0v+3S88rFISInD59GqIH2esIJ8G9O2/XVwhjzpw5EAam1xkkBJn/bJX+v1365hxxuCAfH9+3b9/+////48cPuNehNsS7cDEzMTAwMMzb+Q2u4dOnT2vWrMHu9ZtzxP9vl/69RVpCkBlZ3N7enoDXBwEAAA+YYitOilMVAAAAAElFTkSuQmCC
   :target: https://docs.pyansys.com/
   :alt: PyAnsys

.. |python| image:: https://img.shields.io/pypi/pyversions/ansys-modelcenter-workflow?logo=pypi
   :target: https://pypi.org/project/ansys-modelcenter-workflow/
   :alt: Python

.. |pypi| image:: https://img.shields.io/pypi/v/ansys-modelcenter-workflow.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/ansys-modelcenter-workflow/
   :alt: PyPI

.. |codecov| image:: https://codecov.io/gh/ansys/pymodelcenter/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/ansys/pymodelcenter
   :alt: CodeCov

.. |GH-CI| image:: https://github.com/ansys/pymodelcenter/actions/workflows/ci_cd.yml/badge.svg
   :target: https://github.com/ansys/pymodelcenter/actions/workflows/ci_cd.yml
   :alt: GH-CI

.. |MIT| image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT
   :alt: MIT

.. |black| image:: https://img.shields.io/badge/code_style-black-000000.svg?style=flat
   :target: https://github.com/psf/black
   :alt: Black

.. |pre-commit| image:: https://results.pre-commit.ci/badge/github/ansys/pymodelcenter/main.svg
   :target: https://results.pre-commit.ci/latest/github/ansys/pymodelcenter/main
   :alt: pre-commit

.. index_start

Overview
--------

Ansys ModelCenter Workflow is a Python client library for Ansys ModelCenter,
a suite of products delivering tools for creating and automating engineering workflows.

Documentation and issues
------------------------

Documentation for the latest stable release of Ansys ModelCenter Workflow is hosted
at `Ansys ModelCenter Workflow documentation <https://modelcenter.docs.pyansys.com/version/stable/>`_.

The documentation has four sections:

- `Getting started <https://modelcenter.docs.pyansys.com/version/stable/getting_started/index.html>`_: Learn
  how to install Ansys ModelCenter Workflow.
- `User guide <https://modelcenter.docs.pyansys.com/version/stable/user_guide/index.html>`_: Understand how to
  use Ansys ModelCenter Workflow to create and run workflows.
- `API reference <https://modelcenter.docs.pyansys.com/version/stable/api/index.html>`_: Understand how to use Python
  to interact programmatically with Ansys ModelCenter.
  Workflow API endpoints and how to use them to interact programmatically.
- `Contribute <https://modelcenter.docs.pyansys.com/version/stable/contributing/index.html>`_: Learn how to
  contribute to the Ansys ModelCenter Workflow codebase or documentation.

In the upper right corner of the documentation's title bar, there is an option
for switching from viewing the documentation for the latest stable release
to viewing the documentation for the development version or previously
released versions.

On the `Ansys ModelCenter Workflow Issues <https://github.com/ansys/pymodelcenter/issues>`_
page, you can create issues to report bugs and request new features. On the
`Discussions <https://discuss.ansys.com/>`_ page on the Ansys Developer portal,
you can post questions, share ideas, and get community feedback.

If you have general questions about the PyAnsys ecosystem, email
`pyansys.core@ansys.com <pyansys.core@ansys.com>`_. If your
question is specific to Ansys ModelCenter Workflow, ask your
question in an issue as described in the previous paragraph.

License
-------

Ansys ModelCenter Workflow is licensed under the `MIT License <https://github.com/ansys/pymodelcenter/blob/main/LICENSE>`_.

Ansys ModelCenter Workflow makes no commercial claim over Ansys whatsoever. This library extends the
functionality of interacting with Ansys ModelCenter by adding a Python interface without changing the
core behavior or license of the original software. The use of Ansys ModelCenter requires a legally
licensed copy of Ansys ModelCenter.

To get a copy of Ansys ModelCenter, see the `Ansys ModelCenter <https://www.ansys.com/products/connect/ansys-modelcenter>`_
page on the Ansys website.
